package servlet;
import java.sql.*;

/*
 * Class for managing the database.
 */
public class Database implements AutoCloseable {
	
	// If you have the mysql server on your own computer use "localhost" as server address.
	private static String databaseServerAddress = "vm26.cs.lth.se";
	private static String databaseUser = "<your databse user on vm26>";             // database login user
	private static String databasePassword = "<your password>";          // database login password
	private static String database = "<your database, normally the same as database user>";             // the database to use, i.e. default schema
	private Connection conn = null;
	
	public Database() {
		try{
			conn = DriverManager.getConnection("jdbc:mysql://" + databaseServerAddress + "/" + 
                    database, databaseUser, databasePassword);
			
			// Display the contents of the database in the console. 
			// This should be removed in the final version
			try(Statement stmt = conn.createStatement()) {
				ResultSet rs = stmt.executeQuery("select * from Respondents"); 
				while (rs.next()) {
					String name = rs.getString("name"); 
					System.out.println(name);
				}
			}
			
		} catch (SQLException e) {
			throw new RuntimeException(e);
		}
	}
	
	public boolean addName(String name) {
		String sql = "insert into Respondents (name) values(?)";

		try(PreparedStatement ps = conn.prepareStatement(sql)) {
			ps.setString(1, name);
		    ps.executeUpdate(); 
		    return true;
		} catch (SQLException e) {
		    if(e.getErrorCode()==1062 && e.getSQLState().equals("23000")){ 
		    	// duplicate key error
		    	System.out.println(name + " already exists in the database");
		    } else {
				printSqlError(e);
		    }
			return false;
		}
		// Using the try-with-resources syntax, this will call ps.close() automatically
	}
	
	private void printSqlError(SQLException e){
	    System.out.println("SQLException: " + e.getMessage());
	    System.out.println("SQLState: " + e.getSQLState());
	    System.out.println("VendorError: " + e.getErrorCode());
		throw new RuntimeException(e);
	}

	public void close() throws SQLException {
		conn.close();
	}
}
